@@ -1,19 +1,12 @@
 # -*- coding: utf-8 -*-
 from django.db import models
-from django.core.exceptions import ImproperlyConfigured
-from django.conf import settings
 from django.utils.translation import ugettext as _
-from datetime import datetime
-from vkontakte_api.utils import api_call, VkontakteError
-from vkontakte_api import fields
-from vkontakte_api.models import VkontakteManager, VkontakteIDModel, VkontakteModel, VkontakteContentError
+from vkontakte_api.models import VkontakteManager, VkontakteModel, VkontakteContentError
 from vkontakte_api.decorators import fetch_all
 from vkontakte_groups.models import Group
 from vkontakte_users.models import User
-from dateutil import parser
-from datetime import timedelta, datetime
+from datetime import datetime
 import logging
-from PIL import PdfImagePlugin
 
 log = logging.getLogger('vkontakte_board')
 
@@ -25,10 +18,10 @@ class TopicManager(models.Manager):
 
 class BoardRemoteManager(VkontakteManager):
 
-    def parse_response_list(self, response_list, extra_fields=None):
-        if isinstance(response_list, dict):
-            self.parse_response_users(response_list)
-            return super(BoardRemoteManager, self).parse_response_list(response_list[self.response_instances_fieldname], extra_fields)
+    def parse_response(self, response, extra_fields=None):
+        if isinstance(response, dict):
+            self.parse_response_users(response)
+            return super(BoardRemoteManager, self).parse_response_list(response[self.response_instances_fieldname], extra_fields)
         else:
             raise VkontakteContentError('Vkontakte response should be dict')
 
@@ -118,9 +111,8 @@ class BoardAbstractModel(VkontakteModel):
 
 class Topic(BoardAbstractModel):
     class Meta:
-        db_table = 'vkontakte_board_topic'
-        verbose_name = 'Дискуссия групп Вконтакте'
-        verbose_name_plural = 'Дискуссии групп Вконтакте'
+        verbose_name = u'Дискуссия групп Вконтакте'
+        verbose_name_plural = u'Дискуссии групп Вконтакте'
         ordering = ['remote_id']
 
     remote_pk_field = 'tid'
@@ -137,7 +129,7 @@ class Topic(BoardAbstractModel):
     is_closed = models.BooleanField(u'Закрыта?', help_text=u'Тема является закрытой (в ней нельзя оставлять сообщения)')
     is_fixed = models.BooleanField(u'Прикреплена?', help_text=u'Тема является прилепленной (находится в начале списка тем)')
 
-    comments_count = models.PositiveIntegerField(u'Число сообщений в теме')
+    comments_count = models.PositiveIntegerField(u'Число сообщений в теме', default=0)
 
     first_comment = models.TextField(u'Текст первого сообщения')
     last_comment = models.TextField(u'Текст последнего сообщения')
@@ -170,9 +162,8 @@ class Topic(BoardAbstractModel):
 
 class Comment(BoardAbstractModel):
     class Meta:
-        db_table = 'vkontakte_board_comment'
-        verbose_name = _('Vkontakte group topic comment')
-        verbose_name_plural = _('Vkontakte group topic comments')
+        verbose_name = u'Коммментарий дискуссии групп Вконтакте'
+        verbose_name_plural = u'Коммментарии дискуссий групп Вконтакте'
         ordering = ['remote_id']
 
     topic = models.ForeignKey(Topic, verbose_name=u'Тема', related_name='comments')
@@ -191,12 +182,12 @@ class Comment(BoardAbstractModel):
         return self.slug_prefix + str(self.topic.remote_id) + '?post=' + self.remote_id.split('_')[2]
 
     def parse(self, response):
+        self.author = User.objects.get_or_create(remote_id=response.pop('from_id'))[0]
         # TODO: add parsing attachments and polls
         if 'attachments' in response:
             response.pop('attachments')
         if 'poll' in response:
             response.pop('poll')
-        self.author = User.objects.get_or_create(remote_id=response.pop('from_id'))[0]
 
         super(Comment, self).parse(response)
 
